Class: RelentlessIdentity::ClientBackgroundJobDetailResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/relentless_identity/models/client_background_job_detail_response.rb

Overview

Background job detail plus paginated item results.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClientBackgroundJobDetailResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::ClientBackgroundJobDetailResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::ClientBackgroundJobDetailResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'job')
    self.job = attributes[:'job']
  else
    self.job = nil
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'total_items')
    self.total_items = attributes[:'total_items']
  else
    self.total_items = nil
  end

  if attributes.key?(:'page')
    self.page = attributes[:'page']
  else
    self.page = nil
  end

  if attributes.key?(:'page_size')
    self.page_size = attributes[:'page_size']
  else
    self.page_size = nil
  end

  if attributes.key?(:'total_pages')
    self.total_pages = attributes[:'total_pages']
  else
    self.total_pages = nil
  end

  if attributes.key?(:'results_expired')
    self.results_expired = attributes[:'results_expired']
  end
end

Instance Attribute Details

#itemsObject

Returns the value of attribute items.



21
22
23
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 21

def items
  @items
end

#jobObject

Returns the value of attribute job.



19
20
21
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 19

def job
  @job
end

#pageObject

Returns the value of attribute page.



25
26
27
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 25

def page
  @page
end

#page_sizeObject

Returns the value of attribute page_size.



27
28
29
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 27

def page_size
  @page_size
end

#results_expiredObject

Whether the stored item payload rows have already expired and been pruned.



32
33
34
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 32

def results_expired
  @results_expired
end

#total_itemsObject

Returns the value of attribute total_items.



23
24
25
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 23

def total_items
  @total_items
end

#total_pagesObject

Returns the value of attribute total_pages.



29
30
31
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 29

def total_pages
  @total_pages
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 35

def self.attribute_map
  {
    :'job' => :'job',
    :'items' => :'items',
    :'total_items' => :'total_items',
    :'page' => :'page',
    :'page_size' => :'page_size',
    :'total_pages' => :'total_pages',
    :'results_expired' => :'results_expired'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 58

def self.openapi_types
  {
    :'job' => :'ClientBackgroundJobResponse',
    :'items' => :'Array<ClientBackgroundJobItemResponse>',
    :'total_items' => :'Integer',
    :'page' => :'Integer',
    :'page_size' => :'Integer',
    :'total_pages' => :'Integer',
    :'results_expired' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      job == o.job &&
      items == o.items &&
      total_items == o.total_items &&
      page == o.page &&
      page_size == o.page_size &&
      total_pages == o.total_pages &&
      results_expired == o.results_expired
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 262

def hash
  [job, items, total_items, page, page_size, total_pages, results_expired].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @job.nil?
    invalid_properties.push('invalid value for "job", job cannot be nil.')
  end

  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  if @total_items.nil?
    invalid_properties.push('invalid value for "total_items", total_items cannot be nil.')
  end

  if @page.nil?
    invalid_properties.push('invalid value for "page", page cannot be nil.')
  end

  if @page_size.nil?
    invalid_properties.push('invalid value for "page_size", page_size cannot be nil.')
  end

  if @total_pages.nil?
    invalid_properties.push('invalid value for "total_pages", total_pages cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
177
178
# File 'lib/relentless_identity/models/client_background_job_detail_response.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @job.nil?
  return false if @items.nil?
  return false if @total_items.nil?
  return false if @page.nil?
  return false if @page_size.nil?
  return false if @total_pages.nil?
  true
end