Class: RelentlessIdentity::ClientBackgroundJobPageResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RelentlessIdentity::ClientBackgroundJobPageResponse
- Defined in:
- lib/relentless_identity/models/client_background_job_page_response.rb
Overview
Paginated list of background jobs for the authenticated user.
Instance Attribute Summary collapse
-
#items ⇒ Object
Returns the value of attribute items.
-
#page ⇒ Object
Returns the value of attribute page.
-
#page_size ⇒ Object
Returns the value of attribute page_size.
-
#total ⇒ Object
Returns the value of attribute total.
-
#total_pages ⇒ Object
Returns the value of attribute total_pages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClientBackgroundJobPageResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClientBackgroundJobPageResponse
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::ClientBackgroundJobPageResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::ClientBackgroundJobPageResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end else self.items = nil end if attributes.key?(:'total') self.total = attributes[:'total'] else self.total = nil end if attributes.key?(:'page') self.page = attributes[:'page'] else self.page = nil end if attributes.key?(:'page_size') self.page_size = attributes[:'page_size'] else self.page_size = nil end if attributes.key?(:'total_pages') self.total_pages = attributes[:'total_pages'] else self.total_pages = nil end end |
Instance Attribute Details
#items ⇒ Object
Returns the value of attribute items.
19 20 21 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 19 def items @items end |
#page ⇒ Object
Returns the value of attribute page.
23 24 25 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 23 def page @page end |
#page_size ⇒ Object
Returns the value of attribute page_size.
25 26 27 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 25 def page_size @page_size end |
#total ⇒ Object
Returns the value of attribute total.
21 22 23 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 21 def total @total end |
#total_pages ⇒ Object
Returns the value of attribute total_pages.
27 28 29 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 27 def total_pages @total_pages end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 30 def self.attribute_map { :'items' => :'items', :'total' => :'total', :'page' => :'page', :'page_size' => :'page_size', :'total_pages' => :'total_pages' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 51 def self.openapi_types { :'items' => :'Array<ClientBackgroundJobResponse>', :'total' => :'Integer', :'page' => :'Integer', :'page_size' => :'Integer', :'total_pages' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && items == o.items && total == o.total && page == o.page && page_size == o.page_size && total_pages == o.total_pages end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 226 def hash [items, total, page, page_size, total_pages].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @items.nil? invalid_properties.push('invalid value for "items", items cannot be nil.') end if @total.nil? invalid_properties.push('invalid value for "total", total cannot be nil.') end if @page.nil? invalid_properties.push('invalid value for "page", page cannot be nil.') end if @page_size.nil? invalid_properties.push('invalid value for "page_size", page_size cannot be nil.') end if @total_pages.nil? invalid_properties.push('invalid value for "total_pages", total_pages cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 153 154 |
# File 'lib/relentless_identity/models/client_background_job_page_response.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @items.nil? return false if @total.nil? return false if @page.nil? return false if @page_size.nil? return false if @total_pages.nil? true end |