Class: RelentlessIdentity::ClientIdentityResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RelentlessIdentity::ClientIdentityResponse
- Defined in:
- lib/relentless_identity/models/client_identity_response.rb
Overview
Compact public result envelope used by Finder and Probe style responses.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_alias ⇒ Object
Returns the value of attribute _alias.
-
#address ⇒ Object
Returns the value of attribute address.
-
#identity_providers ⇒ Object
Identity providers associated with the mailbox domain when available.
-
#is_alias ⇒ Object
Whether the resolved address is an alias rather than a primary mailbox.
-
#is_catchall ⇒ Object
Whether the mailbox domain behaved like a catch-all during verification.
-
#mx_hosts ⇒ Object
Observed MX hosts for the mailbox domain.
-
#outcome ⇒ Object
Operational outcome.
-
#request_id ⇒ Object
Returns the value of attribute request_id.
-
#state ⇒ Object
Final public deliverability verdict.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClientIdentityResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClientIdentityResponse
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::ClientIdentityResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::ClientIdentityResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'outcome') self.outcome = attributes[:'outcome'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'is_alias') self.is_alias = attributes[:'is_alias'] end if attributes.key?(:'_alias') self._alias = attributes[:'_alias'] end if attributes.key?(:'is_catchall') self.is_catchall = attributes[:'is_catchall'] end if attributes.key?(:'identity_providers') if (value = attributes[:'identity_providers']).is_a?(Array) self.identity_providers = value end end if attributes.key?(:'mx_hosts') if (value = attributes[:'mx_hosts']).is_a?(Array) self.mx_hosts = value end end if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end end |
Instance Attribute Details
#_alias ⇒ Object
Returns the value of attribute _alias.
30 31 32 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 30 def _alias @_alias end |
#address ⇒ Object
Returns the value of attribute address.
25 26 27 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 25 def address @address end |
#identity_providers ⇒ Object
Identity providers associated with the mailbox domain when available.
36 37 38 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 36 def identity_providers @identity_providers end |
#is_alias ⇒ Object
Whether the resolved address is an alias rather than a primary mailbox.
28 29 30 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 28 def is_alias @is_alias end |
#is_catchall ⇒ Object
Whether the mailbox domain behaved like a catch-all during verification.
33 34 35 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 33 def is_catchall @is_catchall end |
#mx_hosts ⇒ Object
Observed MX hosts for the mailbox domain.
39 40 41 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 39 def mx_hosts @mx_hosts end |
#outcome ⇒ Object
Operational outcome. ‘error` means the verification could not complete cleanly and should not be treated as a negative mailbox verdict.
23 24 25 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 23 def outcome @outcome end |
#request_id ⇒ Object
Returns the value of attribute request_id.
41 42 43 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 41 def request_id @request_id end |
#state ⇒ Object
Final public deliverability verdict.
20 21 22 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 20 def state @state end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 66 def self.attribute_map { :'state' => :'state', :'outcome' => :'outcome', :'address' => :'address', :'is_alias' => :'is_alias', :'_alias' => :'alias', :'is_catchall' => :'is_catchall', :'identity_providers' => :'identity_providers', :'mx_hosts' => :'mx_hosts', :'request_id' => :'request_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 111 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 106 def self.openapi_nullable Set.new([ :'address', :'request_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 91 def self.openapi_types { :'state' => :'String', :'outcome' => :'String', :'address' => :'String', :'is_alias' => :'Boolean', :'_alias' => :'ClientFinderResponseAlias', :'is_catchall' => :'Boolean', :'identity_providers' => :'Array<IdentityProvider>', :'mx_hosts' => :'Array<String>', :'request_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && state == o.state && outcome == o.outcome && address == o.address && is_alias == o.is_alias && _alias == o._alias && is_catchall == o.is_catchall && identity_providers == o.identity_providers && mx_hosts == o.mx_hosts && request_id == o.request_id end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 240 def hash [state, outcome, address, is_alias, _alias, is_catchall, identity_providers, mx_hosts, request_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 194 |
# File 'lib/relentless_identity/models/client_identity_response.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["deliverable", "undeliverable"]) return false unless state_validator.valid?(@state) outcome_validator = EnumAttributeValidator.new('String', ["found", "not_found", "error"]) return false unless outcome_validator.valid?(@outcome) true end |