Class: RelentlessIdentity::ClientTokenStatusResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/relentless_identity/models/client_token_status_response.rb

Overview

Current bearer token claims as seen by the API.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClientTokenStatusResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::ClientTokenStatusResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::ClientTokenStatusResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  else
    self.token_type = nil
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'expires_in_seconds')
    self.expires_in_seconds = attributes[:'expires_in_seconds']
  end
end

Instance Attribute Details

#expires_atObject

Returns the value of attribute expires_at.



31
32
33
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 31

def expires_at
  @expires_at
end

#expires_in_secondsObject

Returns the value of attribute expires_in_seconds.



33
34
35
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 33

def expires_in_seconds
  @expires_in_seconds
end

#scopesObject

Scopes currently attached to the bearer token.



29
30
31
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 29

def scopes
  @scopes
end

#token_typeObject

How the bearer token was issued.



26
27
28
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 26

def token_type
  @token_type
end

#user_idObject

User id associated with the bearer token.



23
24
25
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 23

def user_id
  @user_id
end

#validObject

Whether the current bearer token is valid for this request.



20
21
22
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 20

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 58

def self.attribute_map
  {
    :'valid' => :'valid',
    :'user_id' => :'user_id',
    :'token_type' => :'token_type',
    :'scopes' => :'scopes',
    :'expires_at' => :'expires_at',
    :'expires_in_seconds' => :'expires_in_seconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 92

def self.openapi_nullable
  Set.new([
    :'expires_at',
    :'expires_in_seconds'
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 80

def self.openapi_types
  {
    :'valid' => :'Boolean',
    :'user_id' => :'String',
    :'token_type' => :'String',
    :'scopes' => :'Array<String>',
    :'expires_at' => :'Time',
    :'expires_in_seconds' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      valid == o.valid &&
      user_id == o.user_id &&
      token_type == o.token_type &&
      scopes == o.scopes &&
      expires_at == o.expires_at &&
      expires_in_seconds == o.expires_in_seconds
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 214

def hash
  [valid, user_id, token_type, scopes, expires_at, expires_in_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @token_type.nil?
    invalid_properties.push('invalid value for "token_type", token_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
# File 'lib/relentless_identity/models/client_token_status_response.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @user_id.nil?
  return false if @token_type.nil?
  token_type_validator = EnumAttributeValidator.new('String', ["pat", "oauth"])
  return false unless token_type_validator.valid?(@token_type)
  true
end