Class: RelentlessIdentity::ProbeApi
- Inherits:
-
Object
- Object
- RelentlessIdentity::ProbeApi
- Defined in:
- lib/relentless_identity/api/probe_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ProbeApi
constructor
A new instance of ProbeApi.
-
#probe_batch(probe_batch_request, opts = {}) ⇒ ClientBatchIdentityResponse
Verify many email addresses Send many known email addresses and receive compact per-item identity results plus a batch summary.
-
#probe_batch_with_http_info(probe_batch_request, opts = {}) ⇒ Array<(ClientBatchIdentityResponse, Integer, Hash)>
Verify many email addresses Send many known email addresses and receive compact per-item identity results plus a batch summary.
-
#probe_email(probe_request, opts = {}) ⇒ ClientIdentityResponse
Verify an email address Send a single email address to verify it directly.
-
#probe_email_with_http_info(probe_request, opts = {}) ⇒ Array<(ClientIdentityResponse, Integer, Hash)>
Verify an email address Send a single email address to verify it directly.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/relentless_identity/api/probe_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#probe_batch(probe_batch_request, opts = {}) ⇒ ClientBatchIdentityResponse
Verify many email addresses Send many known email addresses and receive compact per-item identity results plus a batch summary.
27 28 29 30 |
# File 'lib/relentless_identity/api/probe_api.rb', line 27 def probe_batch(probe_batch_request, opts = {}) data, _status_code, _headers = probe_batch_with_http_info(probe_batch_request, opts) data end |
#probe_batch_with_http_info(probe_batch_request, opts = {}) ⇒ Array<(ClientBatchIdentityResponse, Integer, Hash)>
Verify many email addresses Send many known email addresses and receive compact per-item identity results plus a batch summary.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/relentless_identity/api/probe_api.rb', line 37 def probe_batch_with_http_info(probe_batch_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProbeApi.probe_batch ...' end # verify the required parameter 'probe_batch_request' is set if @api_client.config.client_side_validation && probe_batch_request.nil? fail ArgumentError, "Missing the required parameter 'probe_batch_request' when calling ProbeApi.probe_batch" end # resource path local_var_path = '/client/probe/batch' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(probe_batch_request) # return_type return_type = opts[:debug_return_type] || 'ClientBatchIdentityResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProbeApi.probe_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProbeApi#probe_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#probe_email(probe_request, opts = {}) ⇒ ClientIdentityResponse
Verify an email address Send a single email address to verify it directly.
95 96 97 98 |
# File 'lib/relentless_identity/api/probe_api.rb', line 95 def probe_email(probe_request, opts = {}) data, _status_code, _headers = probe_email_with_http_info(probe_request, opts) data end |
#probe_email_with_http_info(probe_request, opts = {}) ⇒ Array<(ClientIdentityResponse, Integer, Hash)>
Verify an email address Send a single email address to verify it directly.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/relentless_identity/api/probe_api.rb', line 105 def probe_email_with_http_info(probe_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProbeApi.probe_email ...' end # verify the required parameter 'probe_request' is set if @api_client.config.client_side_validation && probe_request.nil? fail ArgumentError, "Missing the required parameter 'probe_request' when calling ProbeApi.probe_email" end # resource path local_var_path = '/client/probe' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(probe_request) # return_type return_type = opts[:debug_return_type] || 'ClientIdentityResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProbeApi.probe_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProbeApi#probe_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |