Class: RelentlessIdentity::BatchSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RelentlessIdentity::BatchSummary
- Defined in:
- lib/relentless_identity/models/batch_summary.rb
Instance Attribute Summary collapse
-
#errors ⇒ Object
Items that ended with an operational verification error rather than a mailbox verdict.
-
#found ⇒ Object
Items that resolved to a positive deliverable result.
-
#not_found ⇒ Object
Items that completed cleanly with a negative result.
-
#total ⇒ Object
Total number of requested items.
-
#unique_domains ⇒ Object
Distinct mailbox domains represented in the batch.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BatchSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BatchSummary
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::BatchSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::BatchSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total') self.total = attributes[:'total'] else self.total = nil end if attributes.key?(:'found') self.found = attributes[:'found'] else self.found = nil end if attributes.key?(:'not_found') self.not_found = attributes[:'not_found'] else self.not_found = nil end if attributes.key?(:'errors') self.errors = attributes[:'errors'] else self.errors = nil end if attributes.key?(:'unique_domains') self.unique_domains = attributes[:'unique_domains'] else self.unique_domains = nil end end |
Instance Attribute Details
#errors ⇒ Object
Items that ended with an operational verification error rather than a mailbox verdict.
28 29 30 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 28 def errors @errors end |
#found ⇒ Object
Items that resolved to a positive deliverable result.
22 23 24 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 22 def found @found end |
#not_found ⇒ Object
Items that completed cleanly with a negative result.
25 26 27 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 25 def not_found @not_found end |
#total ⇒ Object
Total number of requested items.
19 20 21 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 19 def total @total end |
#unique_domains ⇒ Object
Distinct mailbox domains represented in the batch.
31 32 33 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 31 def unique_domains @unique_domains end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 34 def self.attribute_map { :'total' => :'total', :'found' => :'found', :'not_found' => :'not_found', :'errors' => :'errors', :'unique_domains' => :'unique_domains' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 280 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 55 def self.openapi_types { :'total' => :'Integer', :'found' => :'Integer', :'not_found' => :'Integer', :'errors' => :'Integer', :'unique_domains' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 255 def ==(o) return true if self.equal?(o) self.class == o.class && total == o.total && found == o.found && not_found == o.not_found && errors == o.errors && unique_domains == o.unique_domains end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 273 def hash [total, found, not_found, errors, unique_domains].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @total.nil? invalid_properties.push('invalid value for "total", total cannot be nil.') end if @total < 0 invalid_properties.push('invalid value for "total", must be greater than or equal to 0.') end if @found.nil? invalid_properties.push('invalid value for "found", found cannot be nil.') end if @found < 0 invalid_properties.push('invalid value for "found", must be greater than or equal to 0.') end if @not_found.nil? invalid_properties.push('invalid value for "not_found", not_found cannot be nil.') end if @not_found < 0 invalid_properties.push('invalid value for "not_found", must be greater than or equal to 0.') end if @errors.nil? invalid_properties.push('invalid value for "errors", errors cannot be nil.') end if @errors < 0 invalid_properties.push('invalid value for "errors", must be greater than or equal to 0.') end if @unique_domains.nil? invalid_properties.push('invalid value for "unique_domains", unique_domains cannot be nil.') end if @unique_domains < 0 invalid_properties.push('invalid value for "unique_domains", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/relentless_identity/models/batch_summary.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @total.nil? return false if @total < 0 return false if @found.nil? return false if @found < 0 return false if @not_found.nil? return false if @not_found < 0 return false if @errors.nil? return false if @errors < 0 return false if @unique_domains.nil? return false if @unique_domains < 0 true end |