Class: RelentlessIdentity::ClientBackgroundJobResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RelentlessIdentity::ClientBackgroundJobResponse
- Defined in:
- lib/relentless_identity/models/client_background_job_response.rb
Overview
Background job status envelope returned by the public jobs API.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#actual_amount_micros ⇒ Object
Returns the value of attribute actual_amount_micros.
-
#artifact_available ⇒ Object
Returns the value of attribute artifact_available.
-
#artifact_json_url ⇒ Object
Returns the value of attribute artifact_json_url.
-
#artifact_size_bytes ⇒ Object
Returns the value of attribute artifact_size_bytes.
-
#artifact_uploaded_at ⇒ Object
Returns the value of attribute artifact_uploaded_at.
-
#callback_attempts ⇒ Object
Returns the value of attribute callback_attempts.
-
#callback_last_error ⇒ Object
Returns the value of attribute callback_last_error.
-
#callback_status ⇒ Object
Returns the value of attribute callback_status.
-
#callback_url ⇒ Object
Returns the value of attribute callback_url.
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#completed_count ⇒ Object
Returns the value of attribute completed_count.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deadline_at ⇒ Object
Returns the value of attribute deadline_at.
-
#error_count ⇒ Object
Returns the value of attribute error_count.
-
#estimated_runtime_seconds ⇒ Object
Returns the value of attribute estimated_runtime_seconds.
-
#history_expires_at ⇒ Object
Returns the value of attribute history_expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#job_type ⇒ Object
Returns the value of attribute job_type.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#not_found_count ⇒ Object
Returns the value of attribute not_found_count.
-
#progress_percent ⇒ Object
Approximate percent complete based on completed item count.
-
#requested_count ⇒ Object
Total number of submitted items for the job.
-
#reserved_amount_micros ⇒ Object
Returns the value of attribute reserved_amount_micros.
-
#results_pruned_at ⇒ Object
Returns the value of attribute results_pruned_at.
-
#scheduled_start_at ⇒ Object
Returns the value of attribute scheduled_start_at.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Current high-level job lifecycle state.
-
#success_count ⇒ Object
Returns the value of attribute success_count.
-
#summary ⇒ Object
Aggregated counts and provider stats for the job.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClientBackgroundJobResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClientBackgroundJobResponse
Initializes the object
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 204 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RelentlessIdentity::ClientBackgroundJobResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RelentlessIdentity::ClientBackgroundJobResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] else self.job_type = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'deadline_at') self.deadline_at = attributes[:'deadline_at'] else self.deadline_at = nil end if attributes.key?(:'estimated_runtime_seconds') self.estimated_runtime_seconds = attributes[:'estimated_runtime_seconds'] else self.estimated_runtime_seconds = nil end if attributes.key?(:'scheduled_start_at') self.scheduled_start_at = attributes[:'scheduled_start_at'] else self.scheduled_start_at = nil end if attributes.key?(:'callback_url') self.callback_url = attributes[:'callback_url'] end if attributes.key?(:'callback_status') self.callback_status = attributes[:'callback_status'] else self.callback_status = nil end if attributes.key?(:'callback_attempts') self.callback_attempts = attributes[:'callback_attempts'] else self.callback_attempts = nil end if attributes.key?(:'callback_last_error') self.callback_last_error = attributes[:'callback_last_error'] end if attributes.key?(:'requested_count') self.requested_count = attributes[:'requested_count'] else self.requested_count = nil end if attributes.key?(:'completed_count') self.completed_count = attributes[:'completed_count'] else self.completed_count = nil end if attributes.key?(:'success_count') self.success_count = attributes[:'success_count'] else self.success_count = nil end if attributes.key?(:'not_found_count') self.not_found_count = attributes[:'not_found_count'] else self.not_found_count = nil end if attributes.key?(:'error_count') self.error_count = attributes[:'error_count'] else self.error_count = nil end if attributes.key?(:'reserved_amount_micros') self.reserved_amount_micros = attributes[:'reserved_amount_micros'] else self.reserved_amount_micros = nil end if attributes.key?(:'actual_amount_micros') self.actual_amount_micros = attributes[:'actual_amount_micros'] else self.actual_amount_micros = nil end if attributes.key?(:'progress_percent') self.progress_percent = attributes[:'progress_percent'] end if attributes.key?(:'summary') if (value = attributes[:'summary']).is_a?(Hash) self.summary = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'history_expires_at') self.history_expires_at = attributes[:'history_expires_at'] end if attributes.key?(:'results_pruned_at') self.results_pruned_at = attributes[:'results_pruned_at'] end if attributes.key?(:'artifact_available') self.artifact_available = attributes[:'artifact_available'] else self.artifact_available = false end if attributes.key?(:'artifact_json_url') self.artifact_json_url = attributes[:'artifact_json_url'] end if attributes.key?(:'artifact_size_bytes') self.artifact_size_bytes = attributes[:'artifact_size_bytes'] end if attributes.key?(:'artifact_uploaded_at') self.artifact_uploaded_at = attributes[:'artifact_uploaded_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#actual_amount_micros ⇒ Object
Returns the value of attribute actual_amount_micros.
53 54 55 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 53 def actual_amount_micros @actual_amount_micros end |
#artifact_available ⇒ Object
Returns the value of attribute artifact_available.
71 72 73 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 71 def artifact_available @artifact_available end |
#artifact_json_url ⇒ Object
Returns the value of attribute artifact_json_url.
73 74 75 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 73 def artifact_json_url @artifact_json_url end |
#artifact_size_bytes ⇒ Object
Returns the value of attribute artifact_size_bytes.
75 76 77 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 75 def artifact_size_bytes @artifact_size_bytes end |
#artifact_uploaded_at ⇒ Object
Returns the value of attribute artifact_uploaded_at.
77 78 79 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 77 def artifact_uploaded_at @artifact_uploaded_at end |
#callback_attempts ⇒ Object
Returns the value of attribute callback_attempts.
36 37 38 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 36 def callback_attempts @callback_attempts end |
#callback_last_error ⇒ Object
Returns the value of attribute callback_last_error.
38 39 40 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 38 def callback_last_error @callback_last_error end |
#callback_status ⇒ Object
Returns the value of attribute callback_status.
34 35 36 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 34 def callback_status @callback_status end |
#callback_url ⇒ Object
Returns the value of attribute callback_url.
32 33 34 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 32 def callback_url @callback_url end |
#completed_at ⇒ Object
Returns the value of attribute completed_at.
65 66 67 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 65 def completed_at @completed_at end |
#completed_count ⇒ Object
Returns the value of attribute completed_count.
43 44 45 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 43 def completed_count @completed_count end |
#created_at ⇒ Object
Returns the value of attribute created_at.
79 80 81 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 79 def created_at @created_at end |
#deadline_at ⇒ Object
Returns the value of attribute deadline_at.
26 27 28 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 26 def deadline_at @deadline_at end |
#error_count ⇒ Object
Returns the value of attribute error_count.
49 50 51 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 49 def error_count @error_count end |
#estimated_runtime_seconds ⇒ Object
Returns the value of attribute estimated_runtime_seconds.
28 29 30 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 28 def estimated_runtime_seconds @estimated_runtime_seconds end |
#history_expires_at ⇒ Object
Returns the value of attribute history_expires_at.
67 68 69 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 67 def history_expires_at @history_expires_at end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 19 def id @id end |
#job_type ⇒ Object
Returns the value of attribute job_type.
21 22 23 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 21 def job_type @job_type end |
#metadata ⇒ Object
Returns the value of attribute metadata.
61 62 63 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 61 def @metadata end |
#not_found_count ⇒ Object
Returns the value of attribute not_found_count.
47 48 49 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 47 def not_found_count @not_found_count end |
#progress_percent ⇒ Object
Approximate percent complete based on completed item count.
56 57 58 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 56 def progress_percent @progress_percent end |
#requested_count ⇒ Object
Total number of submitted items for the job.
41 42 43 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 41 def requested_count @requested_count end |
#reserved_amount_micros ⇒ Object
Returns the value of attribute reserved_amount_micros.
51 52 53 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 51 def reserved_amount_micros @reserved_amount_micros end |
#results_pruned_at ⇒ Object
Returns the value of attribute results_pruned_at.
69 70 71 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 69 def results_pruned_at @results_pruned_at end |
#scheduled_start_at ⇒ Object
Returns the value of attribute scheduled_start_at.
30 31 32 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 30 def scheduled_start_at @scheduled_start_at end |
#started_at ⇒ Object
Returns the value of attribute started_at.
63 64 65 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 63 def started_at @started_at end |
#status ⇒ Object
Current high-level job lifecycle state.
24 25 26 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 24 def status @status end |
#success_count ⇒ Object
Returns the value of attribute success_count.
45 46 47 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 45 def success_count @success_count end |
#summary ⇒ Object
Aggregated counts and provider stats for the job.
59 60 61 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 59 def summary @summary end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
81 82 83 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 81 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
142 143 144 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 142 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
147 148 149 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 147 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 106 def self.attribute_map { :'id' => :'id', :'job_type' => :'job_type', :'status' => :'status', :'deadline_at' => :'deadline_at', :'estimated_runtime_seconds' => :'estimated_runtime_seconds', :'scheduled_start_at' => :'scheduled_start_at', :'callback_url' => :'callback_url', :'callback_status' => :'callback_status', :'callback_attempts' => :'callback_attempts', :'callback_last_error' => :'callback_last_error', :'requested_count' => :'requested_count', :'completed_count' => :'completed_count', :'success_count' => :'success_count', :'not_found_count' => :'not_found_count', :'error_count' => :'error_count', :'reserved_amount_micros' => :'reserved_amount_micros', :'actual_amount_micros' => :'actual_amount_micros', :'progress_percent' => :'progress_percent', :'summary' => :'summary', :'metadata' => :'metadata', :'started_at' => :'started_at', :'completed_at' => :'completed_at', :'history_expires_at' => :'history_expires_at', :'results_pruned_at' => :'results_pruned_at', :'artifact_available' => :'artifact_available', :'artifact_json_url' => :'artifact_json_url', :'artifact_size_bytes' => :'artifact_size_bytes', :'artifact_uploaded_at' => :'artifact_uploaded_at', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 707 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 188 def self.openapi_nullable Set.new([ :'callback_url', :'callback_last_error', :'started_at', :'completed_at', :'history_expires_at', :'results_pruned_at', :'artifact_json_url', :'artifact_size_bytes', :'artifact_uploaded_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 152 def self.openapi_types { :'id' => :'String', :'job_type' => :'String', :'status' => :'String', :'deadline_at' => :'Time', :'estimated_runtime_seconds' => :'Integer', :'scheduled_start_at' => :'Time', :'callback_url' => :'String', :'callback_status' => :'String', :'callback_attempts' => :'Integer', :'callback_last_error' => :'String', :'requested_count' => :'Integer', :'completed_count' => :'Integer', :'success_count' => :'Integer', :'not_found_count' => :'Integer', :'error_count' => :'Integer', :'reserved_amount_micros' => :'Integer', :'actual_amount_micros' => :'Integer', :'progress_percent' => :'Float', :'summary' => :'Hash<String, Object>', :'metadata' => :'Hash<String, Object>', :'started_at' => :'Time', :'completed_at' => :'Time', :'history_expires_at' => :'Time', :'results_pruned_at' => :'Time', :'artifact_available' => :'Boolean', :'artifact_json_url' => :'String', :'artifact_size_bytes' => :'Integer', :'artifact_uploaded_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 657 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && job_type == o.job_type && status == o.status && deadline_at == o.deadline_at && estimated_runtime_seconds == o.estimated_runtime_seconds && scheduled_start_at == o.scheduled_start_at && callback_url == o.callback_url && callback_status == o.callback_status && callback_attempts == o.callback_attempts && callback_last_error == o.callback_last_error && requested_count == o.requested_count && completed_count == o.completed_count && success_count == o.success_count && not_found_count == o.not_found_count && error_count == o.error_count && reserved_amount_micros == o.reserved_amount_micros && actual_amount_micros == o.actual_amount_micros && progress_percent == o.progress_percent && summary == o.summary && == o. && started_at == o.started_at && completed_at == o.completed_at && history_expires_at == o.history_expires_at && results_pruned_at == o.results_pruned_at && artifact_available == o.artifact_available && artifact_json_url == o.artifact_json_url && artifact_size_bytes == o.artifact_size_bytes && artifact_uploaded_at == o.artifact_uploaded_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
694 695 696 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 694 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
700 701 702 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 700 def hash [id, job_type, status, deadline_at, estimated_runtime_seconds, scheduled_start_at, callback_url, callback_status, callback_attempts, callback_last_error, requested_count, completed_count, success_count, not_found_count, error_count, reserved_amount_micros, actual_amount_micros, progress_percent, summary, , started_at, completed_at, history_expires_at, results_pruned_at, artifact_available, artifact_json_url, artifact_size_bytes, artifact_uploaded_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 381 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @job_type.nil? invalid_properties.push('invalid value for "job_type", job_type cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @deadline_at.nil? invalid_properties.push('invalid value for "deadline_at", deadline_at cannot be nil.') end if @estimated_runtime_seconds.nil? invalid_properties.push('invalid value for "estimated_runtime_seconds", estimated_runtime_seconds cannot be nil.') end if @scheduled_start_at.nil? invalid_properties.push('invalid value for "scheduled_start_at", scheduled_start_at cannot be nil.') end if @callback_status.nil? invalid_properties.push('invalid value for "callback_status", callback_status cannot be nil.') end if @callback_attempts.nil? invalid_properties.push('invalid value for "callback_attempts", callback_attempts cannot be nil.') end if @requested_count.nil? invalid_properties.push('invalid value for "requested_count", requested_count cannot be nil.') end if @completed_count.nil? invalid_properties.push('invalid value for "completed_count", completed_count cannot be nil.') end if @success_count.nil? invalid_properties.push('invalid value for "success_count", success_count cannot be nil.') end if @not_found_count.nil? invalid_properties.push('invalid value for "not_found_count", not_found_count cannot be nil.') end if @error_count.nil? invalid_properties.push('invalid value for "error_count", error_count cannot be nil.') end if @reserved_amount_micros.nil? invalid_properties.push('invalid value for "reserved_amount_micros", reserved_amount_micros cannot be nil.') end if @actual_amount_micros.nil? invalid_properties.push('invalid value for "actual_amount_micros", actual_amount_micros cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 729 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/relentless_identity/models/client_background_job_response.rb', line 457 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @job_type.nil? job_type_validator = EnumAttributeValidator.new('String', ["finder_batch", "probe_batch"]) return false unless job_type_validator.valid?(@job_type) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["queued", "processing", "completed", "failed", "canceled"]) return false unless status_validator.valid?(@status) return false if @deadline_at.nil? return false if @estimated_runtime_seconds.nil? return false if @scheduled_start_at.nil? return false if @callback_status.nil? callback_status_validator = EnumAttributeValidator.new('String', ["none", "pending", "delivered", "failed"]) return false unless callback_status_validator.valid?(@callback_status) return false if @callback_attempts.nil? return false if @requested_count.nil? return false if @completed_count.nil? return false if @success_count.nil? return false if @not_found_count.nil? return false if @error_count.nil? return false if @reserved_amount_micros.nil? return false if @actual_amount_micros.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |