Class: RelentlessIdentity::JobsApi
- Inherits:
-
Object
- Object
- RelentlessIdentity::JobsApi
- Defined in:
- lib/relentless_identity/api/jobs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_job(job_id, opts = {}) ⇒ ClientBackgroundJobDetailResponse
Get background job Return the current status and paginated results for one background job.
-
#get_job_inputs_text(job_id, opts = {}) ⇒ String
Download job inputs Return the original background job inputs as plain text when the payload is still retained.
-
#get_job_inputs_text_with_http_info(job_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Download job inputs Return the original background job inputs as plain text when the payload is still retained.
-
#get_job_results_json(job_id, opts = {}) ⇒ Object
Download job results as JSON Return the canonical immutable background job results artifact as JSON.
-
#get_job_results_json_with_http_info(job_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Download job results as JSON Return the canonical immutable background job results artifact as JSON.
-
#get_job_results_text(job_id, opts = {}) ⇒ String
Download job results as text Return the canonical background job results in a readable plain-text format.
-
#get_job_results_text_with_http_info(job_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Download job results as text Return the canonical background job results in a readable plain-text format.
-
#get_job_with_http_info(job_id, opts = {}) ⇒ Array<(ClientBackgroundJobDetailResponse, Integer, Hash)>
Get background job Return the current status and paginated results for one background job.
-
#initialize(api_client = ApiClient.default) ⇒ JobsApi
constructor
A new instance of JobsApi.
-
#list_jobs(opts = {}) ⇒ ClientBackgroundJobPageResponse
List background jobs Return the authenticated user’s paginated background job history.
-
#list_jobs_with_http_info(opts = {}) ⇒ Array<(ClientBackgroundJobPageResponse, Integer, Hash)>
List background jobs Return the authenticated user's paginated background job history.
-
#schedule_finder_batch(finder_batch_job_request, opts = {}) ⇒ ClientBackgroundJobResponse
Schedule a finder batch Queue a background finder batch job with an optional deadline and callback URL.
-
#schedule_finder_batch_with_http_info(finder_batch_job_request, opts = {}) ⇒ Array<(ClientBackgroundJobResponse, Integer, Hash)>
Schedule a finder batch Queue a background finder batch job with an optional deadline and callback URL.
-
#schedule_probe_batch(probe_batch_job_background_request, opts = {}) ⇒ ClientBackgroundJobResponse
Schedule a probe batch Queue a background probe batch job with an optional deadline and callback URL.
-
#schedule_probe_batch_with_http_info(probe_batch_job_background_request, opts = {}) ⇒ Array<(ClientBackgroundJobResponse, Integer, Hash)>
Schedule a probe batch Queue a background probe batch job with an optional deadline and callback URL.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_job(job_id, opts = {}) ⇒ ClientBackgroundJobDetailResponse
Get background job Return the current status and paginated results for one background job.
29 30 31 32 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 29 def get_job(job_id, opts = {}) data, _status_code, _headers = get_job_with_http_info(job_id, opts) data end |
#get_job_inputs_text(job_id, opts = {}) ⇒ String
Download job inputs Return the original background job inputs as plain text when the payload is still retained.
110 111 112 113 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 110 def get_job_inputs_text(job_id, opts = {}) data, _status_code, _headers = get_job_inputs_text_with_http_info(job_id, opts) data end |
#get_job_inputs_text_with_http_info(job_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Download job inputs Return the original background job inputs as plain text when the payload is still retained.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 122 def get_job_inputs_text_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.get_job_inputs_text ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.get_job_inputs_text" end # resource path local_var_path = '/client/jobs/{job_id}/inputs.txt'.sub('{' + 'job_id' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json']) unless header_params['Accept'] header_params[:'if-none-match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'if-modified-since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.get_job_inputs_text", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#get_job_inputs_text\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_job_results_json(job_id, opts = {}) ⇒ Object
Download job results as JSON Return the canonical immutable background job results artifact as JSON.
179 180 181 182 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 179 def get_job_results_json(job_id, opts = {}) data, _status_code, _headers = get_job_results_json_with_http_info(job_id, opts) data end |
#get_job_results_json_with_http_info(job_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Download job results as JSON Return the canonical immutable background job results artifact as JSON.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 191 def get_job_results_json_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.get_job_results_json ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.get_job_results_json" end # resource path local_var_path = '/client/jobs/{job_id}/results.json'.sub('{' + 'job_id' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'if-none-match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'if-modified-since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.get_job_results_json", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#get_job_results_json\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_job_results_text(job_id, opts = {}) ⇒ String
Download job results as text Return the canonical background job results in a readable plain-text format.
248 249 250 251 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 248 def get_job_results_text(job_id, opts = {}) data, _status_code, _headers = get_job_results_text_with_http_info(job_id, opts) data end |
#get_job_results_text_with_http_info(job_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Download job results as text Return the canonical background job results in a readable plain-text format.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 260 def get_job_results_text_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.get_job_results_text ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.get_job_results_text" end # resource path local_var_path = '/client/jobs/{job_id}/results.txt'.sub('{' + 'job_id' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json']) unless header_params['Accept'] header_params[:'if-none-match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'if-modified-since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.get_job_results_text", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#get_job_results_text\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_job_with_http_info(job_id, opts = {}) ⇒ Array<(ClientBackgroundJobDetailResponse, Integer, Hash)>
Get background job Return the current status and paginated results for one background job.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 41 def get_job_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.get_job ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling JobsApi.get_job" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling JobsApi.get_job, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling JobsApi.get_job, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling JobsApi.get_job, must be greater than or equal to 1.' end # resource path local_var_path = '/client/jobs/{job_id}'.sub('{' + 'job_id' + '}', CGI.escape(job_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientBackgroundJobDetailResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.get_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#get_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_jobs(opts = {}) ⇒ ClientBackgroundJobPageResponse
List background jobs Return the authenticated user’s paginated background job history.
318 319 320 321 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 318 def list_jobs(opts = {}) data, _status_code, _headers = list_jobs_with_http_info(opts) data end |
#list_jobs_with_http_info(opts = {}) ⇒ Array<(ClientBackgroundJobPageResponse, Integer, Hash)>
List background jobs Return the authenticated user's paginated background job history.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 331 def list_jobs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.list_jobs ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling JobsApi.list_jobs, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling JobsApi.list_jobs, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling JobsApi.list_jobs, must be greater than or equal to 1.' end allowable_values = ["finder_batch", "probe_batch"] if @api_client.config.client_side_validation && opts[:'job_type'] && !allowable_values.include?(opts[:'job_type']) fail ArgumentError, "invalid value for \"job_type\", must be one of #{allowable_values}" end allowable_values = ["queued", "processing", "completed", "failed", "canceled"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/client/jobs' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'job_type'] = opts[:'job_type'] if !opts[:'job_type'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientBackgroundJobPageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.list_jobs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#list_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#schedule_finder_batch(finder_batch_job_request, opts = {}) ⇒ ClientBackgroundJobResponse
Schedule a finder batch Queue a background finder batch job with an optional deadline and callback URL.
404 405 406 407 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 404 def schedule_finder_batch(finder_batch_job_request, opts = {}) data, _status_code, _headers = schedule_finder_batch_with_http_info(finder_batch_job_request, opts) data end |
#schedule_finder_batch_with_http_info(finder_batch_job_request, opts = {}) ⇒ Array<(ClientBackgroundJobResponse, Integer, Hash)>
Schedule a finder batch Queue a background finder batch job with an optional deadline and callback URL.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 414 def schedule_finder_batch_with_http_info(finder_batch_job_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.schedule_finder_batch ...' end # verify the required parameter 'finder_batch_job_request' is set if @api_client.config.client_side_validation && finder_batch_job_request.nil? fail ArgumentError, "Missing the required parameter 'finder_batch_job_request' when calling JobsApi.schedule_finder_batch" end # resource path local_var_path = '/client/jobs/finder' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(finder_batch_job_request) # return_type return_type = opts[:debug_return_type] || 'ClientBackgroundJobResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.schedule_finder_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#schedule_finder_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#schedule_probe_batch(probe_batch_job_background_request, opts = {}) ⇒ ClientBackgroundJobResponse
Schedule a probe batch Queue a background probe batch job with an optional deadline and callback URL.
472 473 474 475 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 472 def schedule_probe_batch(probe_batch_job_background_request, opts = {}) data, _status_code, _headers = schedule_probe_batch_with_http_info(probe_batch_job_background_request, opts) data end |
#schedule_probe_batch_with_http_info(probe_batch_job_background_request, opts = {}) ⇒ Array<(ClientBackgroundJobResponse, Integer, Hash)>
Schedule a probe batch Queue a background probe batch job with an optional deadline and callback URL.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/relentless_identity/api/jobs_api.rb', line 482 def schedule_probe_batch_with_http_info(probe_batch_job_background_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobsApi.schedule_probe_batch ...' end # verify the required parameter 'probe_batch_job_background_request' is set if @api_client.config.client_side_validation && probe_batch_job_background_request.nil? fail ArgumentError, "Missing the required parameter 'probe_batch_job_background_request' when calling JobsApi.schedule_probe_batch" end # resource path local_var_path = '/client/jobs/probe-batch' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(probe_batch_job_background_request) # return_type return_type = opts[:debug_return_type] || 'ClientBackgroundJobResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"JobsApi.schedule_probe_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobsApi#schedule_probe_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |